*                                                                              .
*                 SAS Program to Score the TIMSS Advanced 1995                 .
*                                Physics Items                                 .
*                        TIMSS Advanced 2008 User Guide                        .
*                                                                              .

SET MPRINT=ON.

DEFINE SCOREIT (TYPE  = !CHAREND('/') /
                ITEM  = !CHAREND('/') /
                RIGHT = !CHAREND('/') /
                NR    = !CHAREND('/') /
                NA    = !CHAREND('/') /
                OM    = !CHAREND('/') /
                OTHER = !CHAREND('/') ) .

* Code for multiple-choice items .

 !IF (!UPCASE(!TYPE)=MC) !THEN
    !DO !I !IN (!ITEM) .
       RECODE !I (!RIGHT = 1      )
                 (!NR    = 0      ) /* Not Reached      */
                 (!NA    = SYSMIS ) /* Not Administered */
                 (!OM    = 0      ) /* Omitted          */
                 (!OTHER = 0      ) /* Other Missing    */
                 (ELSE   = 0      ) .
    !DOEND .
 !IFEND .

 * Code for constructed-response items .

 !IF (!UPCASE(!TYPE)=CR) !THEN
    !DO !I !IN (!ITEM).
       RECODE !I (10 THRU 19 = 1      )
                 (20 THRU 29 = 2      )
                 (30 THRU 39 = 3      )
                 (70 THRU 79 = 0      )
                 (!NR        = 0      ) /* Not Reached      */
                 (!NA        = SYSMIS ) /* Not Administered */
                 (!OM        = 0      ) /* Omitted          */
                 (!OTHER     = 0      ) /* Other Missing    */
                 (ELSE       = 0      ).
    !DOEND .
 !IFEND .

!ENDDEFINE.

DEFINE DOIT (COUNTRY = !CHAREND('/') ) .

* Specify the path for the SPSS data files following the format x:\xxx\ .
* <path> must be edited .

!LET !LIBDAT = !UNQUOTE("<path>") .

* Country loop .

!DO !CTY !IN (!COUNTRY) .

* Get the student achievement data .

ADD FILES
  / FILE = !QUOTE(!CONCAT(!LIBDAT,'PSA',!CTY,'M1.SAV')) .

* Score multiple-choice items with A key .

SCOREIT  Type  = MC      /
         Item  = PA13001  PA13009  PA13021  PA13050  PA13053  PA13057  PA13070
                 PA13071  /
         RIGHT = 1       /
         NR    = 6       /
         NA    = sysmis  /
         OM    = 9       /
         OTHER = 7       .

* Score multiple-choice items with B key .

SCOREIT  Type  = MC      /
         Item  = PA13002  PA13011  PA13014  PA13019  PA13055  PA13058  PA13072
                 PA13074  PA13076  /
         RIGHT = 2       /
         NR    = 6       /
         NA    = sysmis  /
         OM    = 9       /
         OTHER = 7       .

* Score multiple-choice items with C key .

SCOREIT  Type  = MC      /
         Item  = PA13003  PA13005  PA13012  PA13013  PA13015  PA13018  PA13049
                 PA13068  PA13073  PA13077  /
         RIGHT = 3       /
         NR    = 6       /
         NA    = sysmis  /
         OM    = 9       /
         OTHER = 7       .

* Score multiple-choice items with D key .

SCOREIT  Type  = MC       /
         Item  = PA13004  PA13006  PA13016  PA13017  PA13051  PA13054  PA13069
                 PA13075  /
         RIGHT = 4       /
         NR    = 6       /
         NA    = sysmis  /
         OM    = 9       /
         OTHER = 7       .

* Score multiple-choice items with E key .

SCOREIT  Type  = MC       /
         Item  = PA13056  /
         RIGHT = 5       /
         NR    = 6       /
         NA    = sysmis  /
         OM    = 9       /
         OTHER = 7       .

* Score Constructed-Response Items .

SCOREIT  Type  = CR      /
         Item  = PA13022  PA13023  PA13024  PA13025  PA13026  PA13027A PA13059
                 PA13060  PA13062  PA13063  PA13064  PA13065  PA13066  PA13067
                 PA13079  PA13080  PA13081  PA13083  PA13084  PA13085  PA13086A
                 PA13086B  /
         RIGHT =  0      /
         NR    = 96      /
         NA    = sysmis  /
         OM    = 99      /
         OTHER = 90      .

EXECUTE.

* Save the student data .

SAVE OUTFILE = !QUOTE(!CONCAT(!LIBDAT,'PSC',!CTY,'M1.SAV')) .

!DOEND .

!ENDDEFINE .

* Specify the list of countries to be processed .

DOIT COUNTRY = AUS AUT CAN CYP CZE FRA DEU DNK GRC ISR
               LVA NOR RUS SVN SWE CHE USA .
